<?php
/* 
 * Function to set and read session variables
 */
define('SESSION_USER_ID','userid');
define('SESSION_USER_NAME', 'username');
define('SESSION_USER_GM', 'userGM');
define('SESSION_CHARACTER_ID', 'CharID');

/**
 * 
 */
require_once('database/DatabaseAccess.php');

define('SESSIONS_TABLE', 'session_variables');
define('SESSIONS_ID', 'session_id');
define('SESSIONS_ACCESS', 'access_time');
define('SESSIONS_DATA', 'data');

$sessDbHandle;

/**
 * Open the sessions database.
 * 
 * @global type $sessDbHandle
 */
function _open() {
    global $sessDbHandle;
    
    $sessDbHandle = openDatabase();
}

/**
 * Close the sessions database.
 * 
 * @global type $sessDbHandle
 */
function _close() {
    global $sessDbHandle;
    
    // no close with PDO
}

/**
 * Return an array of all data for given session id.
 * 
 * @global type $sessDbHandle
 * @param type $_id
 * @return type
 */
function _read($_id)
{
    global $sessDbHandle;
 
    $sql = "select ".SESSIONS_DATA." from ".SESSIONS_TABLE." where ".SESSIONS_ID."=?;";

    try {
        $statementHandle = $sessDbHandle->prepare($sql);

        $statementHandle->execute(array($_id));
        
        $result = $statementHandle->fetch();

        return $result[SESSIONS_DATA];
    }
    catch (PDOException $exception) {
        logError($exception);
    }
    
    return null;
}

/**
 * Insert or update session data for id.
 * 
 * @global type $sessDbHandle
 * @param type $id
 * @param type $data
 * @return type
 */
function _write($_id, $_data)
{
    global $sessDbHandle;
        
    // create array time of access
    $params = array(time(), $_data, $_id);
    
    if (is_null($sessDbHandle)) {
        $sessDbHandle = openDatabase();
    }
 
    // check for existing entry for session
    $sqlSelect = "select ".SESSIONS_DATA." from ".SESSIONS_TABLE." where ".SESSIONS_ID."=?;";

    try {
        $statementHandle = $sessDbHandle->prepare($sqlSelect);

        $statementHandle->execute(array($_id));
    }
    catch (PDOException $exception) {
        logError($exception);
    }
 
    if ($statementHandle->fetch()) {
        // entries for session do update
        $sql = "update ".SESSIONS_TABLE." set ".SESSIONS_ACCESS."=?"
                        .",".SESSIONS_DATA."=? where ".SESSIONS_ID."=?;";
    }
    else {
        // no entries for session do insert
        $sql = "insert into ".SESSIONS_TABLE." (".SESSIONS_ACCESS.",".SESSIONS_DATA.",".SESSIONS_ID.")"
                        ." values (?,?,?);";
    }

    try {
        $statementHandle = $sessDbHandle->prepare($sql);

        $statementHandle->execute($params);
        return true;
    }
    catch (PDOException $exception) {
        databaseError($exception);
    }

    return false;
}

/**
 * Remove all the data for session id.
 * 
 * @global type $sessDbHandle
 * @param type $_id
 * @return boolean
 */
function _destroy($_id)
{
    global $sessDbHandle;
 
    $sql = "delete from ".SESSIONS_TABLE." where ".SESSIONS_ID."=?;";
    
    try {
        $statementHandle = $sessDbHandle->prepare($sql);

        $statementHandle->execute(array($_id));
        
        return true;
    }
    catch (PDOException $exception) {
        logError($exception);
    }
 
    return false;
}

/**
 * Garbage collection
 * @global type $sessDbHandle
 * @param type $maxTime
 * @return type
 */
function _gc($maxTime)
{
    global $sessDbHandle;
 
    $params = array(time() - $maxTime);
    
    $sql = "delete from ".SESSIONS_TABLE." where ".SESSIONS_ACCESS."<?;";

    try {
        $statementHandle = $sessDbHandle->prepare($sql);

        $statementHandle->execute($params);
        
        return true;
    }
    catch (PDOException $exception) {
        logError($exception);
    }
 
    return false;
}

/**
 * Get a session data for all logged in users who have been active in the last X milliseconds.
 * 
 * @param type $_dbHandle
 * @param type $_params
 * @return boolean
 */
function getAllLoggedInUsersData($_dbHandle, $_params) {
    $sql = "select ".SESSIONS_DATA." from ".SESSIONS_TABLE." where ".SESSIONS_ACCESS." > ?;";

    $return = false;
    
    try {
        $statementHandle = $_dbHandle->prepare($sql);

        $statementHandle->execute($_params);

        $rows = $statementHandle->FetchAll();
        
        // decode data for each user
        foreach ($rows as $row) {
            $return[] = decodeUserSessionData($row[0]);      
        }
  
        return $return;
    }
    catch (PDOException $exception) {
        logDatabaseError($exception);
    }
 
    return false;
}

/**
 * Decode user's session data. Only string, int and boolean are recogonised.
 * 
 * Format: data_string|s:4:"Ryan";data_int|i:1;data_boolean|b:1
 * 
 * @param type $_data
 * @return boolean
 */
function decodeUserSessionData($_data) {
    // separate parameters
    $parameters = explode(';', $_data);
    
    $return = false;
    
    // decode each parameter name and value type/value
    foreach($parameters as $parameter) {
        if (strlen($parameter)>1) {
            $keyValue = explode('|', $parameter);

            $value = explode(':', $keyValue[1]);

            switch ($value[0]) {
                case 's':
                    // string, remove "s
                    $return[$keyValue[0]] = str_replace('"', '', $value[2]);
                    break;
                case 'i':
                    // integer
                    $return[$keyValue[0]] = $value[1];
                    break;
                case 'b':
                    if ($value[1] == '1') {
                        $return[$keyValue[0]] = true;
                    } else {
                        $return[$keyValue[0]] = false;
                    }
                    break;
                default:
                    // skip, not recognised
                    break;
            }
        }
    }

    return $return;
}

/**
 * Point session handler to functions above
 */
session_set_save_handler('_open',
                         '_close',
                         '_read',
                         '_write',
                         '_destroy',
                         '_gc');

session_start();