<?php

/* 
 * Queries for Career and Specialisation tables
 */

define('CAREERS_TABLE', 'Careers');
define('CAREERS_ID', 'CareerID');
define('CAREERS_TITLE', 'Title');

define('CAREER_SKILLS_TABLE', '[Career Skills]');
define('CAREER_SKILLS_CAREER_ID', 'CareerID');
define('CAREER_SKILLS_ID', 'ID');
define('CAREER_SKILLS_SKILL_ID', 'SkillID');

define('SKILL_NAMES_TABLE', '[Skill Names]');
define('SKILL_NAMES_ID', 'ID');
define('SKILL_NAMES_NAME', 'Name');

define('CAREER_TO_SPECIALISATIONS_TABLE', 'CareerToSpecialisations');
define('CAREER_TO_SPECIALISATIONS_CAREER_ID', 'CareerID');
define('CAREER_TO_SPECIALISATIONS_SPECIALISATION_ID', 'SpecialisationID');

define('SPECIALISATIONS_TABLE', 'Specialisations');
define('SPECIALISATION_ID', 'SpecialisationID');
define('SPECIALISATION_NAME', 'Specialisation');
define('TALENT_TREE_ID', 'TalentTreeID');

define('SPECIALISATIONS_TO_SKILLS_TABLE', '[SpecialisationToSkills]');
define('SPECIALISATIONS_TO_SKILLS_SPECIALISATION_ID', 'SpecialisationID');
define('SPECIALISATIONS_TO_SKILLS_SKILL_ID', 'SkillID');

define('CHARACTER_CAREER_SKILLS_TABLE', 'CharacterCareerSkills');
define('CHARACTER_CAREER_SKILLS_CHARACTER_ID', 'CharacterID');
define('CHARACTER_CAREER_SKILLS_SKILL_ID', 'SkillID');

define('CHARACTER_TABLE', 'Character');
define('CHARACTER_CHARACTER_ID', 'CharacterID');
define('CHARACTER_CAREER_ID', 'CareerID');

define('CHARACTER_TO_SPECIALISATIONS_TABLE', 'CharacterToSpecialisations');
define('CHARACTER_TO_SPECIALISATIONS_CHARACTER_ID', 'CharacterID');
define('CHARACTER_TO_SPECIALISATIONS_SPECIALISATION_ID', 'SpecialisationID');

define('SKILLS_TABLE', 'Skills');
define('SKILLS_CHARACTER_ID', 'CharacterID');

/**
 * Return a handle for query that lists all Careers.
 * 
 * Return false if query failed.
 */
function getAllCareers($_dbHandle) {
	$sql = "select * from ".CAREERS_TABLE." order by ".CAREERS_TITLE.";";
	try {
		$statementHandle = $_dbHandle->query($sql);

		return $statementHandle->fetchAll();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;
}

/**
 * Return a handle for query that lists all data for a selected Career.
 * 
 * Return false if query failed.
 */
function getAllForCareer($_dbHandle, $_params) {
	$sql = "select * from ".CAREERS_TABLE." where ".CAREERS_ID." = ?;";
	try {
		$statementHandle = $_dbHandle->prepare($sql);
		$statementHandle->execute($_params); 

		return $statementHandle->fetch();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;
}

/**
 * Return a handle for query that lists all Career Skills in a set Career.
 * 
 * Return false if query failed.
 */
function getCareerSkills($_dbHandle, $_params) {
	$sql = "SELECT ".CAREER_SKILLS_TABLE.".".CAREER_SKILLS_CAREER_ID.", ".SKILL_NAMES_TABLE.".".SKILL_NAMES_NAME.", ".SKILL_NAMES_TABLE.".".SKILL_NAMES_ID."
			FROM ".SKILL_NAMES_TABLE." INNER JOIN ".CAREER_SKILLS_TABLE." ON ".SKILL_NAMES_TABLE.".".SKILL_NAMES_ID." = ".CAREER_SKILLS_TABLE.".".CAREER_SKILLS_SKILL_ID."
			WHERE (((".CAREER_SKILLS_TABLE.".".CAREER_SKILLS_CAREER_ID.")=?));";

	try {
		$statementHandle = $_dbHandle->prepare($sql);
		$statementHandle->execute($_params); 

		return $statementHandle->fetchAll();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;
}

/**
 * Return a handle for query that lists all Specialisation in a set Career.
 * 
 * Return false if query failed.
 */
function getCareerSpecialisations($_dbHandle, $_params) {
	$sql = "SELECT ".SPECIALISATIONS_TABLE.".".SPECIALISATION_ID.", ".SPECIALISATIONS_TABLE.".".SPECIALISATION_NAME."
			FROM ".SPECIALISATIONS_TABLE." INNER JOIN ".CAREER_TO_SPECIALISATIONS_TABLE." ON ".SPECIALISATIONS_TABLE.".".SPECIALISATION_ID." = ".CAREER_TO_SPECIALISATIONS_TABLE.".".CAREER_TO_SPECIALISATIONS_SPECIALISATION_ID."
			WHERE (((".CAREER_TO_SPECIALISATIONS_TABLE.".".CAREER_TO_SPECIALISATIONS_CAREER_ID.")=?));";
	try {
		$statementHandle = $_dbHandle->prepare($sql);
		$statementHandle->execute($_params); 

		return $statementHandle->fetchAll();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;
}

/**
 * Return a handle for query that lists all Career Skills in a set Specialisation.
 * 
 * Return false if query failed.
 */
function getSpecialisationSkills($_dbHandle, $_params) {
	$sql = "SELECT ".SKILL_NAMES_TABLE.".".SKILL_NAMES_NAME.", ".SKILL_NAMES_TABLE.".".SKILL_NAMES_ID."
			FROM ".SKILL_NAMES_TABLE." INNER JOIN ".SPECIALISATIONS_TO_SKILLS_TABLE." ON ".SKILL_NAMES_TABLE.".ID = ".SPECIALISATIONS_TO_SKILLS_TABLE.".".SPECIALISATIONS_TO_SKILLS_SKILL_ID."
			WHERE (((".SPECIALISATIONS_TO_SKILLS_TABLE.".".SPECIALISATIONS_TO_SKILLS_SPECIALISATION_ID.")=?));";
	try {
		$statementHandle = $_dbHandle->prepare($sql);
		$statementHandle->execute($_params); 

		return $statementHandle->fetchAll();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;
}


/**
 * Set Career for Character.
 * 
 * Return false if query failed.
 */
function setCharacterCareer($_dbHandle, $_params) {
	$sql = "update ".CHARACTER_TABLE." set ".CHARACTER_CAREER_ID."=? where ".CHARACTER_CHARACTER_ID."=?;";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
	}
	catch (PDOException $exception) {
		databaseError($exception);

	}
	return false;
}

/**
 * Set Specialisation for Character.
 * 
 * Return false if query failed.
 */
function setCharacterSpecialisation($_dbHandle, $_params) {
	$sql = "insert into ".CHARACTER_TO_SPECIALISATIONS_TABLE." (".CHARACTER_TO_SPECIALISATIONS_CHARACTER_ID.", ".CHARACTER_TO_SPECIALISATIONS_SPECIALISATION_ID.") values (?,?);";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
	return false;
}

/**
 * Set Career Skill for Character.
 * 
 * Return false if query failed.
 */
function setCharacterCareerSkill($_dbHandle, $_params) {
	$sql = "insert into ".CHARACTER_CAREER_SKILLS_TABLE." (".CHARACTER_CAREER_SKILLS_CHARACTER_ID.", ".CHARACTER_CAREER_SKILLS_SKILL_ID.") values (?,?);";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
	return false;
}

/**
 * Return a handle for query that returns the skill names corresponding to the selected skill IDs.
 * 
 * Return false if query failed.
 */
function getSelectedSkillNames($_dbHandle, $_params) {
	$sql = "SELECT ".SKILL_NAMES_TABLE.".".SKILL_NAMES_NAME."
			FROM ".SKILL_NAMES_TABLE."
			WHERE ".SKILL_NAMES_ID."=? or ".SKILL_NAMES_ID."=? or ".SKILL_NAMES_ID."=? or ".SKILL_NAMES_ID."=? or ".SKILL_NAMES_ID."=? or ".SKILL_NAMES_ID."=?;";

	try {
		$statementHandle = $_dbHandle->prepare($sql);
		$statementHandle->execute($_params); 

		return $statementHandle->fetchAll();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;
}

/**
 * Set Career Skill rank to 1 for Character.
 * 
 * Return false if query failed.
 */
function setCharacterCareerSkillRank1($_dbHandle, $_fieldName, $_params) {
	$sql = "update ".SKILLS_TABLE." set [".$_fieldName."]=1 where ".SKILLS_CHARACTER_ID."=?;";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
	return false;
}

/**
 * Delete all Career Skills for Character.
 * 
 * Return false if query failed.
 */
function deleteAllCharacterCareerSkills($_dbHandle, $_params) {
	$sql = "delete from ".CHARACTER_CAREER_SKILLS_TABLE." where ".CHARACTER_CAREER_SKILLS_CHARACTER_ID."=?;";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
	return false;
}