<?php

/* 
 * Queries for (owned) Armor, Gear and Weapons tables
 */

define('OWNED_ARMOR_TABLE', 'OwnedArmor');
define('OWNED_ARMOR_CHARACTER_ID', 'CharacterID');
define('OWNED_ARMOR_ARMOR_ID', 'ArmorID');

define('ARMOR_TABLE', 'Armor');
define('ARMOR_ID', 'ID');
define('ARMOR_TYPE', 'Type');
define('ARMOR_DEF', 'Defense');
define('ARMOR_SOAK', 'Soak');
define('ARMOR_PRICE', 'Price');
define('ARMOR_ENC', 'Encumberance');
define('ARMOR_HP', 'Hard Points');
define('ARMOR_RARITY', 'Rarity');

define('OWNED_GEAR_TABLE', 'OwnedGear');
define('OWNED_GEAR_CHARACTER_ID', 'CharacterID');
define('OWNED_GEAR_GEAR_ID', 'GearID');

define('GEAR_TABLE', 'Gear');
define('GEAR_ID', 'ID');
define('GEAR_ITEM', 'Item');
define('GEAR_ENC', 'Encumberance');
define('GEAR_PRICE', 'Price');
define('GEAR_RARITY', 'Rarity');

define('OWNED_WEAPONS_TABLE', 'OwnedWeapons');
define('OWNED_WEAPONS_CHARACTER_ID', 'CharacterID');
define('OWNED_WEAPONS_WEAPON_ID', 'WeaponID');

define('WEAPONS_TABLE', 'Weapons');
define('WEAPON_ID', 'ID');
define('WEAPON_NAME', 'Name');
define('WEAPON_SKILL', 'Skill');
define('WEAPON_DMG', 'Damage');
define('WEAPON_CRIT', 'Critical');
define('WEAPON_RANGE', 'Range');
define('WEAPON_ENC', 'Encumberance');
define('WEAPON_HP', 'Hard Points');
define('WEAPON_PRICE', 'Price');
define('WEAPON_RARITY', 'Rarity');
define('WEAPON_SPECIAL', 'Special');

/**
 * Return a handle for query that lists a character's owned armor.
 * 
 * Return false if query failed.
 */
function getCharacterArmor($_dbHandle, $_params) {
	$sql = "SELECT ".ARMOR_TABLE.".*
			FROM ".ARMOR_TABLE.", ".OWNED_ARMOR_TABLE." 
			WHERE ".ARMOR_TABLE.".".ARMOR_ID." = ".OWNED_ARMOR_ARMOR_ID." AND ".OWNED_ARMOR_CHARACTER_ID."=?;";

	try {
		$statementHandle = $_dbHandle->prepare($sql);
		$statementHandle->execute($_params);

		return $statementHandle->fetchAll();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;
}

/**
 * Return a handle for query that lists a character's owned gear.
 * 
 * Return false if query failed.
 */
function getCharacterGear($_dbHandle, $_params) {
	$sql = "SELECT ".GEAR_TABLE.".*
			FROM ".GEAR_TABLE.", ".OWNED_GEAR_TABLE." 
			WHERE ".GEAR_TABLE.".".GEAR_ID." = ".OWNED_GEAR_GEAR_ID." AND ".OWNED_GEAR_CHARACTER_ID."=?;";

	try {
		$statementHandle = $_dbHandle->prepare($sql);
		$statementHandle->execute($_params);

		return $statementHandle->fetchAll();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;
}

/**
 * Return a handle for query that lists a character's owned weapons
 * 
 * Return false if query failed.
 */
function getCharacterWeapons($_dbHandle, $_params) {
	$sql = "SELECT ".WEAPONS_TABLE.".*
			FROM ".WEAPONS_TABLE.", ".OWNED_WEAPONS_TABLE." 
			WHERE ".WEAPONS_TABLE.".".WEAPON_ID." = ".OWNED_WEAPONS_WEAPON_ID." AND ".OWNED_WEAPONS_CHARACTER_ID."=?;";

	try {
		$statementHandle = $_dbHandle->prepare($sql);
		$statementHandle->execute($_params);

		return $statementHandle->fetchAll();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;
}

/**
 * Return a handle for query that lists all Armor.
 * 
 * Return false if query failed.
 */
function getAllArmor($_dbHandle) {
	$sql = "select * from ".ARMOR_TABLE.";";
	try {
		$statementHandle = $_dbHandle->query($sql);

		return $statementHandle->fetchAll();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
    
	return false;
}

/**
 * Return a handle for query that lists all Gear.
 * 
 * Return false if query failed.
 */
function getAllGear($_dbHandle) {
	$sql = "select * from ".GEAR_TABLE.";";
	
	try {
		$statementHandle = $_dbHandle->query($sql);

		return $statementHandle->fetchAll();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
    
	return false;
}

/**
 * Return a handle for query that lists all Weapons.
 * 
 * Return false if query failed.
 */
function getAllWeapons($_dbHandle) {
	$sql = "select * from ".WEAPONS_TABLE.";";
	
	try {
		$statementHandle = $_dbHandle->query($sql);

		return $statementHandle->fetchAll();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
    
	return false;
}

/**
 * Add Weapon to Character.
 * 
 * Return false if query failed.
 */
function addCharacterWeapon($_dbHandle, $_params) {
	$sql = "insert into ".OWNED_WEAPONS_TABLE." (".OWNED_WEAPONS_CHARACTER_ID.", ".OWNED_WEAPONS_WEAPON_ID.") values (?,?);";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
		return True;
	}
	catch (PDOException $exception) {
		databaseError($exception);
		return False;
	}
}

/**
 * Add Armor to Character.
 * 
 * Return false if query failed.
 */
function addCharacterArmor($_dbHandle, $_params) {
	$sql = "insert into ".OWNED_ARMOR_TABLE." (".OWNED_ARMOR_CHARACTER_ID.", ".OWNED_ARMOR_ARMOR_ID.") values (?,?);";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
		return True;
	}
	catch (PDOException $exception) {
		databaseError($exception);
		return False;
	}
}

/**
 * Add Gear to Character.
 * 
 * Return false if query failed.
 */
function addCharacterGear($_dbHandle, $_params) {
	$sql = "insert into ".OWNED_GEAR_TABLE." (".OWNED_GEAR_CHARACTER_ID.", ".OWNED_GEAR_GEAR_ID.") values (?,?);";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
		return True;
	}
	catch (PDOException $exception) {
		databaseError($exception);
		return False;
	}
}