<?php

/* 
 * Queries for Character page
 */

define('CHARACTER_TABLE', 'Character');
define('CHARACTER_ID', 'CharacterID');
define('CHARACTER_USER_ID', 'UserID');
define('CHARACTER_NAME', 'CharName');
define('CHARACTER_GAME_ID', 'GameID');
define('CHARACTER_CURRENT', 'Current');

define('GAMES_TABLE', 'Games');
define('GAMES_NAME', 'Name');
define('GAMES_ID', 'ID');
define('GAMES_GM_ID', 'GMID');

define('CHARACTERS_IN_GAME_TABLE', 'CharactersInGame');
define('CHARACTERS_IN_GAME_GAME_ID', 'GameID');
define('CHARACTERS_IN_GAME_CHARACTER_ID', 'CharacterID');

define('USER_TABLE', 'User');
define('USER_ID', 'ID');
define('USER_USERNAME', 'Username');
define('USER_GM', 'GM');

/**
 * Creates character in character table.
 * 
 * Return false if query failed.
 */
function setInitialCharacter($_dbHandle, $_params) {
	$sql = "insert into ".CHARACTER_TABLE." (".CHARACTER_USER_ID.",".CHARACTER_NAME.")"." values (?,?);";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
	return false;
}

/**
 * Get user's characters from character table.
 * 
 * Return false if query failed.
 */
function getUserCharacters($_dbHandle, $_params) {
	$sql = "select ".CHARACTER_NAME.", ".CHARACTER_TABLE.".".CHARACTER_ID.", ".USER_TABLE.".*, ".GAMES_TABLE.".* 
			from ".CHARACTER_TABLE.", ".USER_TABLE.", ".GAMES_TABLE.", ".CHARACTERS_IN_GAME_TABLE.
			" where ".CHARACTER_USER_ID." =? and "
			.USER_TABLE.".".USER_ID." = ".CHARACTER_TABLE.".".CHARACTER_USER_ID." and "
			.CHARACTERS_IN_GAME_TABLE.".".CHARACTERS_IN_GAME_CHARACTER_ID." = ".CHARACTER_TABLE.".".CHARACTER_ID." and "
			.GAMES_TABLE.".".GAMES_ID." = ".CHARACTERS_IN_GAME_TABLE.".".CHARACTERS_IN_GAME_GAME_ID." and "
			.CHARACTER_TABLE.".".CHARACTER_CURRENT."=true;";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
		return $statementHandle->fetchAll();

	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
	return false;
}

/**
 * Return a handle for query that lists all games.
 * 
 * Return false if query failed.
 */
function getAllGames($_dbHandle) {
	$sql = "select * from ".GAMES_TABLE." order by ".GAMES_NAME.";";
	try {
		$statementHandle = $_dbHandle->prepare($sql);
		$statementHandle->execute($_params); 

		return $statementHandle->fetchAll();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;
}

/**
 * Add new game into Games table.
 * 
 * Return false if query failed.
 */
function createGame($_dbHandle, $_params) {
	$sql = "insert into ".GAMES_TABLE." (".GAMES_NAME.",".GAMES_GM_ID.")"." values (?,?);";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
	return false;
}

/**
 * Get newest character from character table.
 * 
 * Return false if query failed.
 */
function getNewestCharacter($_dbHandle, $_params) {
	$sql = "select max(".CHARACTER_ID.") from ".CHARACTER_TABLE." where ".CHARACTER_USER_ID." =? ;";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
		$row = $statementHandle->fetch();
		return $row[0];
	}
	catch (PDOException $exception) {
		databaseError($exception);
		return false;
	}
}

/**
 * Add character Id and game Id to CharactersInGame.
 * 
 * Return false if query failed.
 */
function addCharacterToGame($_dbHandle, $_params) {
	$sql = "insert into ".CHARACTERS_IN_GAME_TABLE." (".CHARACTERS_IN_GAME_CHARACTER_ID.", ".CHARACTERS_IN_GAME_GAME_ID.")".
			" values (?,?);";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
	return false;
}

/**
 * Get characters in GM's games.
 * 
 * Return false if query failed.
 */
function getGMGameCharacters($_dbHandle, $_params) {
	$sql = "select ".CHARACTER_NAME.", ".CHARACTER_TABLE.".".CHARACTER_ID.", ".USER_TABLE.".*, ".GAMES_TABLE.".* 
			from ".CHARACTER_TABLE.", ".USER_TABLE.", ".GAMES_TABLE.", ".CHARACTERS_IN_GAME_TABLE.
			" where ".GAMES_GM_ID." =? and "
			.USER_TABLE.".".USER_ID." = ".CHARACTER_TABLE.".".CHARACTER_USER_ID." and "
			.CHARACTERS_IN_GAME_TABLE.".".CHARACTERS_IN_GAME_CHARACTER_ID." = ".CHARACTER_TABLE.".".CHARACTER_ID." and "
			.GAMES_TABLE.".".GAMES_ID." = ".CHARACTERS_IN_GAME_TABLE.".".CHARACTERS_IN_GAME_GAME_ID." and "
			.CHARACTER_TABLE.".".CHARACTER_CURRENT."=true;";

	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
		return $statementHandle->fetchAll();

	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
	return false;
}

/**
 * Delete character from character table.
 * 
 * Return false if query failed.
 */
function deleteCharacters($_dbHandle, $_params) {
	$sql = "update ".CHARACTER_TABLE." set Current=false where ".CHARACTER_ID."=?;";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);

	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
	return false;
}

