<?php

/* 
 * Queries for Skills, Skill Names and Character tables
 */

define('SKILLS_TABLE', 'Skills');
define('SKILL_NAMES_TABLE', '[Skill Names]');
define('SKILL_NAMES_ID', 'ID');
define('SKILL_NAMES_NAME', 'Name');
define('SKILLS_CHARACTER_ID', 'CharacterID');

define('CHARACTER_TABLE', 'Character');
define('CHARACTER_NAME', 'CharName');
define('CHARACTER_CHARACTER_ID', 'CharacterID');

/**
 * Return a handle for query that returns all skill names.
 * 
 * Return false if query failed.
 */
function getSkillNames($_dbHandle) {
	$sql = "SELECT ".SKILL_NAMES_TABLE.".* FROM ".SKILL_NAMES_TABLE.";";

	try {
		$statementHandle = $_dbHandle->query($sql);

		return $statementHandle->fetchAll();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;
}

/**
 * Return a handle for query that returns all the skill ranks for a given character.
 * 
 * Return false if query failed.
 */
function getCharacterSkillRanks($_dbHandle, $_params) {
	$sql = "SELECT ".SKILLS_TABLE.".*
			FROM ".SKILLS_TABLE."
			WHERE ".SKILLS_TABLE.".".SKILLS_CHARACTER_ID."=?;";

	try {
		$statementHandle = $_dbHandle->prepare($sql);
		$statementHandle->execute($_params); 

		return $statementHandle->fetch();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;
}

/**
 * Return a handle for query that returns all the characteristics for a given character.
 * 
 * Return false if query failed.
 */
function getCharacteristics($_dbHandle, $_params) {
	$sql = "SELECT * 
			FROM ".CHARACTER_TABLE."
			WHERE ".CHARACTER_TABLE.".".CHARACTER_CHARACTER_ID."=?;";

	try {
		$statementHandle = $_dbHandle->prepare($sql);
		$statementHandle->execute($_params); 

		return $statementHandle->fetch();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;
}

/**
 * Creates character in skills table.
 * 
 * Return false if query failed.
 */
function insertCharacterToSkills($_dbHandle, $_params) {
	$sql = "insert into ".SKILLS_TABLE." (".SKILLS_CHARACTER_ID.") values (?);";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
	return false;
}

/**
 * Increase/Decrease Characteristic rank depending on input.
 * 
 * Return false if query failed.
 */
function updateCharacteristicRank($_dbHandle, $_fieldName, $_params) {
	$sql = "update ".CHARACTER_TABLE." set [".$_fieldName."] = [".$_fieldName."]+? where ".CHARACTER_CHARACTER_ID."=?;";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);

		return True;
	}
	catch (PDOException $exception) {
		databaseError($exception);
		return False;
	}
}

/**
 * Increase/Decrease Skill rank depending on input.
 * 
 * Return false if query failed.
 */
function updateSkillRank($_dbHandle, $_fieldName, $_params) {
	$sql = "update ".SKILLS_TABLE." set [".$_fieldName."] = [".$_fieldName."]+? where ".SKILLS_CHARACTER_ID."=?;";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);

		return True;
	}
	catch (PDOException $exception) {
		databaseError($exception);
		return False;
	}
}