<?php

/* 
 * Queries for Species table
 */

define('SPECIES_TABLE', 'Species');
define('SPECIES_ID', 'ID');
define('SPECIES_NAME', 'Name');
define('SPECIES_BRAWN', 'Brawn');
define('SPECIES_AGILITY', 'Agility');
define('SPECIES_INTELLECT', 'Intellect');
define('SPECIES_CUNNING', 'Cunning');
define('SPECIES_WILLPOWER', 'Willpower');
define('SPECIES_PRESENCE', 'Presence');
define('SPECIES_WOUNDS', 'Wounds');
define('SPECIES_STRAIN', 'Strain');
define('SPECIES_STARTEXP', 'StartExp');
define('SPECIES_ABILITIES', 'Abilities');
define('SPECIES_IMAGE', 'Image');

define('CHARACTER_TABLE', 'Character');
define('CHARACTER_ID', 'CharacterID');
define('CHARACTER_USER_ID', 'UserID');
define('CHARACTER_SPECIES_ID', 'SpeciesID');
define('CHARACTER_BRAWN', 'Brawn');
define('CHARACTER_AGILITY', 'Agility');
define('CHARACTER_INTELLECT', 'Intellect');
define('CHARACTER_CUNNING', 'Cunning');
define('CHARACTER_WILLPOWER', 'Willpower');
define('CHARACTER_PRESENCE', 'Presence');
define('CHARACTER_WOUNDS', 'Wounds');
define('CHARACTER_STRAIN', 'Strain');
define('CHARACTER_EXP', 'Experience');

/**
 * Return a handle for query that lists all Species.
 * 
 * Return false if query failed.
 */
function getAllSpeciesNames($_dbHandle) {
	$sql = "select * from ".SPECIES_TABLE." order by ".SPECIES_NAME.";";
	try {
		$statementHandle = $_dbHandle->query($sql);

		return $statementHandle->fetchAll();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;

}

/**
 * Get selected Species values from table.
 * 
 * Return false if query failed.
 */
function getSpecies($_dbHandle, $_params) {
	$sql = "select * from ".SPECIES_TABLE." where ".SPECIES_ID." = ?;";
	try {
		$statementHandle = $_dbHandle->prepare($sql);
		$statementHandle->execute($_params); 

		return $statementHandle->fetch();
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}

	return false;
}

/**
 * Set selected Species to character table.
 * 
 * Return false if query failed.
 */
function setInitialCharacterSpecies($_dbHandle, $_params) {
	$sql = "update ".CHARACTER_TABLE." set ".CHARACTER_SPECIES_ID."=? where ".CHARACTER_USER_ID."=? and ".CHARACTER_ID."=?;";
			
	try {
		$statementHandle = $_dbHandle->prepare($sql);

		$statementHandle->execute($_params);
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
}

/**
 * Set selected Species and attributes to character table.
 * 
 * Return false if query failed.
 */
function setCharacterSpecies($_dbHandle, $_params) {
	$sql = "UPDATE ".SPECIES_TABLE.", ".CHARACTER_TABLE.
			" SET ".CHARACTER_TABLE.".".CHARACTER_BRAWN." = ".SPECIES_TABLE.".".SPECIES_BRAWN.
            ", ".CHARACTER_TABLE.".".CHARACTER_AGILITY." = ".SPECIES_TABLE.".".SPECIES_AGILITY.
            ", ".CHARACTER_TABLE.".".CHARACTER_INTELLECT." = ".SPECIES_TABLE.".".SPECIES_INTELLECT.
            ", ".CHARACTER_TABLE.".".CHARACTER_CUNNING." = ".SPECIES_TABLE.".".SPECIES_CUNNING.
            ", ".CHARACTER_TABLE.".".CHARACTER_WILLPOWER." = ".SPECIES_TABLE.".".SPECIES_WILLPOWER.
            ", ".CHARACTER_TABLE.".".CHARACTER_PRESENCE." = ".SPECIES_TABLE.".".SPECIES_PRESENCE.
            ", ".CHARACTER_TABLE.".".CHARACTER_WOUNDS." = ".SPECIES_TABLE.".".SPECIES_WOUNDS."+".SPECIES_TABLE.".".SPECIES_BRAWN.
            ", ".CHARACTER_TABLE.".".CHARACTER_STRAIN." = ".SPECIES_TABLE.".".SPECIES_STRAIN."+".SPECIES_TABLE.".".SPECIES_WILLPOWER.
            ", ".CHARACTER_TABLE.".".CHARACTER_EXP." = ".SPECIES_TABLE.".".SPECIES_STARTEXP.
            " WHERE ".CHARACTER_TABLE.".".CHARACTER_ID."=? and ".SPECIES_TABLE.".".SPECIES_ID." = ".CHARACTER_TABLE.".".CHARACTER_SPECIES_ID.";";
				
	try {
		$statementHandle = $_dbHandle->prepare($sql);
		$statementHandle->execute($_params);
	}
	catch (PDOException $exception) {
		databaseError($exception);
	}
}