<?php
	require_once('database/SessionVariables.php');

	define('PAGE_TITLE', 'Character - Background');
	define('FILENAME', basename(__FILE__, '.php'));
	define('SPECIES_SELECTED', 'selected');

	require_once('database/DatabaseAccess.php');
	require_once('database/TableSpecies.php');

	$dbHandle = openDatabase();
	$userID = $_SESSION[SESSION_USER_ID];
	$currentCharacterID = $_SESSION[SESSION_CHARACTER_ID];
	$speciesID = filter_input(INPUT_GET, SPECIES_ID, FILTER_SANITIZE_NUMBER_INT);
	$speciesSelected = filter_input(INPUT_GET, SPECIES_SELECTED, FILTER_VALIDATE_BOOLEAN);

	require_once('includes/header.php');

	if (!is_null($speciesID)) {
		if (!is_null($speciesSelected) && $speciesSelected) {
			setCharacterSpecies($dbHandle, array($currentCharacterID));
			header('location:career.php');
			die();
		}
		else {
			$currentCharacterID = $_SESSION[SESSION_CHARACTER_ID];
			setInitialCharacterSpecies($dbHandle, array($speciesID, $userID, $currentCharacterID));
		}	
	}	
?>
		<div class = "container">
			<div class = "row">
				<div class = "col-md-8 col-md-offset-2">
					<div class="table-responsive">
						<table class="table table-striped">
							<thead>
								<tr>
									<th>Total Experience</th>
									<th>Unspent Experience</th>
									<th>Credits</th>
								</tr>
							</thead>
							<tbody>
								<tr>
									<td>200</td>
									<td>25</td>
									<td>1055</td>
								</tr>
							</tbody>
						</table>
					</div>
				</div>
				<div class="col-md-1 col-md-offset-1">
					<button type="button" class="btn btn-info centered" data-container="body" data-toggle="modal" data-target="#help"><span class="glyphicon glyphicon-question-sign"></span></button>
				</div>
			</div>
		</div>

		<div class = "container">
			<div class = "row">
				<div class = "col-md-6">
					<h2 class="sub-header">Select Species:</h2>
					<form method="get" action="">
						<select class="form-control" name="<?php echo SPECIES_ID ?>" onchange="this.form.submit()">
							<option value="">Choose species...</option>
							<?php
							$species = filter_input(INPUT_GET, SPECIES_ID, FILTER_SANITIZE_STRING);

							$rows = getAllSpeciesNames($dbHandle);
							foreach ($rows as $row) {
								 
								if (strcmp($species, $row[SPECIES_ID]) == 0) {
									echo '<option value="'.$row[SPECIES_ID].'" selected = "selected" >'.$row[SPECIES_NAME].'</option>';
								}
								else {
									echo '<option value="'.$row[SPECIES_ID].'">'.$row[SPECIES_NAME].'</option>';
								}							
							}
							?>
						</select>
				</div>
				<div class = "col-md-6">
					<?php
						if (is_null($species) || strlen($species)==0) {
							echo '<h3 class = "text-center">Please choose a species</h3>';
						}
						else {
							$row = getSpecies($dbHandle, array($species));
					?>
					<h3 class = "text-center"><?php echo $row[SPECIES_NAME];?></h3>
					<div class="table-responsive">
						<input type="hidden" name="<?php echo SPECIES_SELECTED?>" value="true">
						<table class="table table-bordered text-center">
							<thead>
								<tr>
									<th>Brawn</th>
									<th>Agility</th>
									<th>Intellect</th>
									<th>Cunning</th>
									<th>Willpower</th>
									<th>Presence</th>
								</tr>
							</thead>
							<tbody>
								<tr>
									<td><?php echo $row[SPECIES_BRAWN];?></td>
									<td><?php echo $row[SPECIES_AGILITY];?></td>
									<td><?php echo $row[SPECIES_INTELLECT];?></td>
									<td><?php echo $row[SPECIES_CUNNING];?></td>
									<td><?php echo $row[SPECIES_WILLPOWER];?></td>
									<td><?php echo $row[SPECIES_PRESENCE];?></td>
								</tr>
							</tbody>
						</table>
					</div>
					<img class = "img-responsive img-rounded center-block" src="Images\<?php echo $row[SPECIES_IMAGE];?>" alt="Image of <?php echo $row[SPECIES_NAME];?>" style="height:300px;">
					<div class="table-responsive">
						<table class="table table-striped">
							<tbody>
								<tr>
									<td>Wound Threshold:</td>
									<td><?php echo $row[SPECIES_WOUNDS];?> + Brawn</td>
								</tr>
								<tr>
									<td>Strain Threshold</td>
									<td><?php echo $row[SPECIES_STRAIN];?> + Willpower</td>
								</tr>
								<tr>
									<td>Starting Experience</td>
									<td><?php echo $row[SPECIES_STARTEXP];?></td>
								</tr>
								<tr>
									<td>Special Abilities</td>
									<td><?php echo $row[SPECIES_ABILITIES];?></td>
								</tr>
							</tbody>
						</table>
					</div>
					
				</div>
				<div class="container col-md-6 col-md-offset-3">
				<button type="button" class="btn btn-primary btn-lg btn-block" onclick="this.form.submit()">Save</button>
				</div>
				</form>
				<?php
					}
				?>
			</div>
		</div>

		<script src="https://ajax.googleapis.com/ajax/libs/jquery/2.2.0/jquery.min.js"></script>
		<script src="js/bootstrap.js"></script>
		<script src="js/sorttable.js"></script> <!--http://www.kryogenix.org/code/browser/sorttable/-->
	
	</body>
</html>

<!-- Help Modal -->
<div class="modal fade" id="help" tabindex="-1" role="dialog" aria-labelledby="myModalLabel">
	<div class="modal-dialog" role="document">
		<div class="modal-content">
			<div class="modal-header">
				<button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
				<h4 class="modal-title" id="myModalLabel">Help Information</h4>
			</div>
			<div class="modal-body">
				Help info
			</div>
		</div>
	</div>
</div>